// ignore_for_file: use_build_context_synchronously

import 'dart:convert';

import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:intl/intl.dart';
import 'package:mobile_pos/mobile_pos_method_channel.dart';
import 'package:mobile_pos/mobile_pos_platform_interface.dart';
import 'package:mobile_pos/mobile_pos_sdk.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/logger.dart';
import 'package:mobile_pos/src/models/bluetooth_model.dart';
import 'package:mobile_pos/src/models/raven_const.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/card_payment/connect_bluetooth.dart';
import 'package:mobile_pos/src/views/card_payment/insert_card.dart';

String loadAsset(String asset) {
  return "packages/mobile_pos/assets/images/$asset";
}

Future<dynamic> pushRoute(BuildContext context, Widget page) async {
  await Navigator.push(
    context,
    MaterialPageRoute(
      builder: (context) => page,
    ),
  );
  return;
}

Future<dynamic> replaceRoute(BuildContext context, Widget page) async {
  Navigator.pushReplacement(
    context,
    MaterialPageRoute(
      builder: (context) => page,
    ),
  );
  return;
}

Future<void> toRavenPayHome(BuildContext context) async {
  if (MethodChannelMobilePos.paymentAmount != null) {
    RavenBankBoxPlugin.close(context);
    return;
  }
  Navigator.popUntil(context, ModalRoute.withName("raven_pay"));
}

String formatAmount(double amount, {String? type}) {
  var format = NumberFormat(type ?? '#,##0', 'en_US');
  String formattedAmount;

  // checks when amount is zero or null
  if (amount != 0) {
    formattedAmount = format.format(amount);
  } else {
    formattedAmount = '0';
  }

  return formattedAmount;
}

Future<String?> encryptString(String data) async {
  var encryptText = ""; //await FlutterAesEcbPkcs5.encryptString(data, eKey);
  return encryptText;
}

Future<String?> decryptString(String data) async {
  var decryptText = ""; // await FlutterAesEcbPkcs5.decryptString(data, eKey);
  return decryptText;
}

void showSnack(BuildContext context, String msg, {SnackBarBehavior? floating}) {
  ScaffoldMessenger.of(context).showSnackBar(SnackBar(
    margin: const EdgeInsets.symmetric(horizontal: 16, vertical: 4),
    backgroundColor: Colors.black,
    behavior: SnackBarBehavior.floating,
    content: Text(
      msg,
      textAlign: TextAlign.start,
      style: bodyText.copyWith(fontSize: 14.0, color: Colors.white),
    ),
  ));
}

String? validateInput(String? data, {String? errorMessage, int minCount = 4}) {
  if (data!.trim().length < minCount) {
    return errorMessage ?? 'Invalid input';
  } else {
    return null;
  }
}

String getMid(String paramDownload) {
  String param = paramDownload.substring(24, 39);
  return param;
}

String getBusinessName(String paramDownload) {
  var value =
      paramDownload.substring(paramDownload.length - 40, paramDownload.length);
  return value;
}

void copyToClipBoard(BuildContext context,
    {required String data, String? msg}) async {
  await Clipboard.setData(ClipboardData(text: data));
  showSnack(context, msg ?? 'Text Copied!');
}

String refineMeaning(response) {
  String message = '';

  if (response == 'failed') {
    message = 'Failed - TimeOut';
    return message;
  }

  if (response['data']['data'] != null) {
    message = response['data']['data']['meaning'].toString();
  }

  if (message.isEmpty) {
    if (response['data']['meaning'] != null) {
      message = response['data']['meaning'].toString();
    }
  }

  if (message.isEmpty) {
    if (response['data']['message'] != null) {
      message = response['data']['message'].toString();
    } else {
      message = 'Reason unknown';
    }
  }

  return message;
}

Future<bool> checkInternetConnection() async {
  try {
    var connectivityResult = await Connectivity().checkConnectivity();
    return connectivityResult == ConnectivityResult.mobile ||
        connectivityResult == ConnectivityResult.wifi;
  } catch (e) {
    // An error occurred, which may indicate no internet connection
    return false;
  }
}

extension StringExtension on String {
  String capitalize() {
    List<String> splitted = split(" ");
    for (int x = 0; x < splitted.length; x++) {
      if (splitted[x].isEmpty) {
        splitted[x] = splitted[x];
        continue;
      }
      splitted[x] =
          "${splitted[x][0].toUpperCase()}${splitted[x].substring(1).toLowerCase()}";
    }

    return splitted.fold<String>(
        "", (previousValue, element) => "$previousValue$element ");
  }
}

class DateFormatter {
  static String format(DateTime? date, {String format = 'dd/MM/yy'}) {
    if (date == null) {
      return '- -';
    }
    return DateFormat(format).format(date);
  }
}

String currencyNoSymbol(double amount) {
  var format = NumberFormat('#,##0', 'en_US');

  String formattedAmount;

  // checks when amount is zero or null
  if (amount != 0) {
    formattedAmount = format.format(amount);
  } else {
    formattedAmount = '0';
  }

  return formattedAmount;
}

String currencyNoSymbol2(double amount, {String? formateForm}) {
  var format = NumberFormat(formateForm ?? '#,##0.00', 'en_US');

  String formattedAmount;

  // checks when amount is zero or null
  if (amount != 0) {
    formattedAmount = format.format(amount);
  } else {
    formattedAmount = '0.00';
  }

  return formattedAmount;
}

String formateDateGetOnlyDate(DateTime date) {
  return DateFormat('d MMMM, y', 'en_US').format(date);
}

String formateDateGetOnlyTime(DateTime date) {
  return DateFormat('h:mm a', 'en_US').format(date);
}

String formateDateForTranx(DateTime date) {
  final DateFormat formatter = DateFormat('yyyy-MM-dd');
  final String formattedDate = formatter.format(date);
  return formattedDate;
}

String formatCardPan(String cardPan) {
  return cardPan.isEmpty
      ? ""
      : '${cardPan.substring(0, 6)}******${cardPan.substring(cardPan.length - 4, cardPan.length)}';
}

String formatExpiry(String expiry) {
  return "${expiry.substring(2)}/${expiry.substring(0, 2)}";
}

Future<void> processPayment(
    {required amount, required BuildContext context}) async {
  var response = await MobilePosPlatform.instance.chargeCard(context,
      amount: double.parse(amount),
      accountType: '00',
      connectivityType: ConnectivityType.bluetooth);

  try {
    var device = jsonDecode(response!);
    if ((device as Map<String, dynamic>).containsKey("clearMasterKey")) {
      pluginConfig.appInfo.deviceName = device['deviceLabel'];
      bluetoothModel = BluetoothModel.fromJson(device);
      MethodChannelMobilePos.bluetoothConnected.value = true;
      pushRoute(
          context,
          InsertCard(
            paymentType: PaymentType.card,
            deviceName: pluginConfig.appInfo.deviceName ?? "",
            amount: double.tryParse(amount) ?? 0.0,
          ));
      return;
    }
  } catch (ex) {
    logData(ex.toString());
  }

  pushRoute(
      context,
      ConnectBluetooth(
        amount: double.tryParse(amount) ?? 0.0,
      ));
}
