import 'dart:convert';

class BankBoxTransactionModel {
  final List<Transaction> transactions;
  final Pagination pagination;

  BankBoxTransactionModel({
    required this.transactions,
    required this.pagination,
  });

  factory BankBoxTransactionModel.fromJson(Map<String, dynamic> json) =>
      BankBoxTransactionModel(
        transactions: List<Transaction>.from(
            json["transactions"].map((x) => Transaction.fromJson(x))),
        pagination: Pagination.fromJson(json["pagination"]),
      );

  Map<String, dynamic> toJson() => {
        "transactions": List<dynamic>.from(transactions.map((x) => x.toJson())),
        "pagination": pagination.toJson(),
      };
}

class Pagination {
  final int perPage;
  final int currentPage;
  final dynamic nextPage;
  final dynamic prevPage;
  final int totalPages;
  final int total;

  Pagination({
    required this.perPage,
    required this.currentPage,
    required this.nextPage,
    required this.prevPage,
    required this.totalPages,
    required this.total,
  });

  factory Pagination.fromJson(Map<String, dynamic> json) => Pagination(
        perPage: json["perPage"],
        currentPage: json["currentPage"],
        nextPage: json["nextPage"],
        prevPage: json["prevPage"],
        totalPages: json["totalPages"],
        total: json["total"],
      );

  Map<String, dynamic> toJson() => {
        "perPage": perPage,
        "currentPage": currentPage,
        "nextPage": nextPage,
        "prevPage": prevPage,
        "totalPages": totalPages,
        "total": total,
      };
}

class Transaction {
  final int id;
  final String? direction;
  final String? email;
  final String? type;
  int disputeStatus;
  final String? reference;
  final String? bBefore;
  final String? bAfter;
  final String? amount;
  final String? fee;
  final int? stampDuty;
  final String? gross;
  final String? vat;
  final String? pnl;
  final String? channel;
  final String? tId;
  final String? serial;
  final String? stan;
  final dynamic cashier;
  final String? metaData;
  final String? pdonMeta;
  final String? businessEmail;
  final String? issuingAppId;
  final String? rrn;
  final int? status;
  final DateTime? createdAt;
  final dynamic deletedAt;
  final PaymentTransactionData paymentData;

  Transaction(
      {required this.id,
      this.direction,
      this.email,
      this.type,
      required this.disputeStatus,
      this.reference,
      this.bBefore,
      this.bAfter,
      this.amount,
      this.fee,
      this.stampDuty,
      this.gross,
      this.vat,
      this.pnl,
      this.channel,
      this.tId,
      this.serial,
      this.stan,
      this.cashier,
      this.metaData,
      this.pdonMeta,
      this.businessEmail,
      this.issuingAppId,
      this.rrn,
      this.status,
      this.createdAt,
      this.deletedAt,
      required this.paymentData});

  factory Transaction.fromJson(Map<String, dynamic> json) => Transaction(
      id: json["id"],
      direction: json["direction"] ?? '',
      email: json["email"],
      type: json["type"],
      disputeStatus: json["dispute_status"] ?? 0,
      reference: json["reference"],
      bBefore: json["b_before"],
      bAfter: json["b_after"],
      amount: json["amount"],
      fee: json["fee"],
      stampDuty: json["stamp_duty"],
      gross: json["gross"],
      vat: json["vat"],
      pnl: json["pnl"],
      channel: json["channel"],
      tId: json["t_id"],
      serial: json["serial"],
      stan: json["stan"] ?? "",
      cashier: json["cashier"],
      metaData: json["meta_data"],
      pdonMeta: json["pdon_meta"],
      businessEmail: json["business_email"],
      issuingAppId: json["issuing_app_id"],
      rrn: json["rrn"] ?? "",
      status: json["status"],
      createdAt: DateTime.parse(json["created_at"]),
      deletedAt: json["deleted_at"],
      paymentData: PaymentTransactionData.fromJson(
          jsonDecode(json['meta_data'] ?? "{}")));

  Map<String, dynamic> toJson() => {
        "id": id,
        "direction": direction,
        "email": email,
        "type": type,
        "dispute_status": disputeStatus,
        "reference": reference,
        "b_before": bBefore,
        "b_after": bAfter,
        "amount": amount,
        "fee": fee,
        "stamp_duty": stampDuty,
        "gross": gross,
        "vat": vat,
        "pnl": pnl,
        "channel": channel,
        "t_id": tId,
        "serial": serial,
        "stan": stan,
        "cashier": cashier,
        "meta_data": metaData,
        "pdon_meta": pdonMeta,
        "business_email": businessEmail,
        "issuing_app_id": issuingAppId,
        "rrn": rrn,
        "status": status,
        "created_at": (createdAt)?.toIso8601String(),
        "deleted_at": deletedAt,
      };
}

class PaymentTransactionData {
  final String serial;
  final String terminalId;
  final String cardPan;
  final String processorTimestamp;
  final String stan;
  final String rrn;
  final String merchantId;
  final String cardExpiry;
  final String authId;
  final String responseCode;
  final String responseMeaning;
  final String trnxType;
  final double merchantSettlement;
  final double merchantFee;

  PaymentTransactionData({
    required this.serial,
    required this.terminalId,
    required this.cardPan,
    required this.processorTimestamp,
    required this.stan,
    required this.rrn,
    required this.merchantId,
    required this.cardExpiry,
    required this.authId,
    required this.responseCode,
    required this.responseMeaning,
    required this.trnxType,
    required this.merchantSettlement,
    required this.merchantFee,
  });
  String get maskedPAN => cardPan.isEmpty
      ? ""
      : '${cardPan.substring(0, 6)}******${cardPan.substring(cardPan.length - 4, cardPan.length)}';
  factory PaymentTransactionData.fromJson(Map<String, dynamic> json) =>
      PaymentTransactionData(
        serial: json["serial"] ?? "",
        terminalId: json["terminal_id"] ?? "",
        cardPan: json["card_pan"] ?? "",
        processorTimestamp: json["processor_timestamp"] ?? "",
        stan: json["stan"] ?? "",
        rrn: json["rrn"] ?? "",
        merchantId: json["merchant_id"] ?? "",
        cardExpiry: json["card_expiry"] ?? "",
        authId: json["auth_id"] ?? "",
        responseCode: (json["response_code"] ?? "").toString(),
        responseMeaning: json["response_meaning"] ?? "",
        trnxType: json["trnx_type"] ?? "",
        merchantSettlement: (json["merchant_settlement"] ?? 0)?.toDouble(),
        merchantFee: (json["merchant_fee"] ?? 0)?.toDouble(),
      );
}
