import 'package:flutter/material.dart';
import 'package:mobile_pos/mobile_pos_sdk.dart';

class BankBoxConfig {
  ///Called when a user clicks the close button
  ///Add your own close logic is the default does not yield good behaviour
  final void Function()? onClose;

  ///Called when a transaction completes successfully
  final Function(dynamic) onSuccess;

  ///Called when a transaction fails
  final Function(BankBoxException exception) onError;

  ///Defaults to [RavenMobilePOSEnvironment.staging],
  final BankBoxEnvironment environment;

  ///Customise the look and feel of the plugin
  MobilePOSTheme? theme;

  ///Contains details about this app instance
  AppInfo appInfo;

  ///Set to true if you wish to show the powered by Raven label at the bottom
  final bool showLabel;

  ///Information about current user
  CustomerInfo customerInfo;

  ///allow to show user terminals
  final bool showTerminals;

  ///allow user to be able to check balance from BankBox
  final bool enableBalanceCheck;

  ///A widget that show up as logo on plugin homepage
  final Widget? logo;

  ///allow sound to be played on successful transaction
  final bool? enableSuccessSound;

  BankBoxConfig(
      {required this.onSuccess,
      required this.onError,
      required this.appInfo,
      this.onClose,
      this.enableBalanceCheck = true,
      this.showTerminals = true,
      this.showLabel = true,
      this.theme,
      this.enableSuccessSound = true,
      this.logo,
      required this.customerInfo,
      this.environment = BankBoxEnvironment.staging})
      : super() {
    theme = theme ?? MobilePOSTheme.defaults();
  }

  bool get isStaging => environment == BankBoxEnvironment.staging;
}
