import 'package:flutter/material.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';

class BankBoxSelector extends StatelessWidget {
  final List<String> items;
  final int itemSelected;
  final double? height;
  final double? fontSize;
  final Function(int) onChanged;

  const BankBoxSelector({
    this.items = const [],
    this.height,
    this.itemSelected = 0,
    this.fontSize = 14,
    required this.onChanged,
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
        padding: const EdgeInsets.symmetric(horizontal: 6, vertical: 6),
        height: height ?? 52,
        decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(32),
            color: pluginTheme.isLightTheme
                ? AppColors.borderGrey
                : AppColors.ravenPayGrey.withOpacity(0.3)),
        child: Row(
          children: items
              .asMap()
              .map((index, value) => MapEntry(
                    index,
                    item(
                        name: items[index],
                        selected: itemSelected == index,
                        context: context,
                        onTap: () => onChanged(index)),
                  ))
              .values
              .toList(),
        ));
  }

  Widget item(
      {required String name,
      required bool selected,
      required BuildContext context,
      required Function onTap}) {
    return Expanded(
        child: Material(
      color: Colors.transparent,
      child: InkWell(
          borderRadius: BorderRadius.circular(32),
          onTap: () => onTap(),
          child: Container(
              padding: const EdgeInsets.symmetric(horizontal: 8),
              alignment: Alignment.center,
              height: double.infinity,
              decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(32),
                  color: selected ? pluginTheme.getFGColor : null),
              child: FittedBox(
                child: Text(name,
                    style: selected
                        ? headling1.copyWith(
                            fontSize: fontSize,
                            color: pluginTheme.isLightTheme
                                ? AppColors.ravenPayDark
                                : Colors.white,
                            fontWeight: FontWeight.w500,
                          )
                        : subtitle.copyWith(
                            fontWeight: FontWeight.w500,
                            fontSize: fontSize,
                          )),
              ))),
    ));
  }
}
