import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';

class DeviceDisconnectSheet extends StatelessWidget {
  final Function onPressed;
  final String deviceName;
  const DeviceDisconnectSheet(
      {super.key, required this.onPressed, required this.deviceName});

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisSize: MainAxisSize.min,
        children: [
          const Gap(16),
          const RavenPayBottomSheetCapsule(),
          const Gap(20),
          Row(
            children: [
              Container(
                padding: const EdgeInsets.symmetric(horizontal: 4, vertical: 4),
                decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(12),
                    color: pluginTheme.primaryColor.withOpacity(0.2)),
                child: Icon(Icons.bluetooth,
                    size: 20, color: pluginTheme.primaryColor),
              ),
              const Spacer(),
              InkWell(
                onTap: () {
                  Navigator.pop(context);
                },
                child: const RoundedItemContainer(asset: "cancel_icon.png"),
              )
            ],
          ),
          const Gap(20),
          SizedBox(
            width: double.infinity,
            child: Row(
              children: [
                Text("Connected",
                    style: headling1.copyWith(
                        color: pluginTheme.primaryColor, fontSize: 20)),
                Container(
                  margin: const EdgeInsets.symmetric(horizontal: 4),
                  height: 6,
                  width: 6,
                  decoration: BoxDecoration(
                      color: headling2.color, shape: BoxShape.circle),
                ),
                Expanded(
                  child: Text(deviceName,
                      maxLines: 1,
                      overflow: TextOverflow.ellipsis,
                      style: headling1.copyWith(
                          color: headling2.color, fontSize: 20)),
                ),
              ],
            ),
          ),
          const Gap(16),
          Text(
              "You are connected to $deviceName device, you can choose a disconnect and choose a different bluetooth connection by clicking the button below. ",
              style: bodyText.copyWith(
                  color: AppColors.ravenPayGrey,
                  fontSize: 14,
                  fontWeight: FontWeight.w500)),
          const Gap(34),
          RavenPayButton(
            buttonText: "Switch Connection",
            onPressed: () => onPressed(),
          ),
          const Gap(20),
        ],
      ),
    );
  }
}
