import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';

class BankBoxExpansionTile extends StatefulWidget {
  final EdgeInsets? padding;
  final Widget? animatedChild;
  final int animatedTime;
  final Widget? leading;
  final String? title;
  final bool showBorder;
  final Color? iconColor;
  final double borderSpacing;
  final double actionIconSize;
  final Widget? statusWidget;
  final double childSpacing;

  const BankBoxExpansionTile(
      {super.key,
      this.title,
      this.leading,
      this.padding,
      this.iconColor,
      this.borderSpacing = 4,
      this.actionIconSize = 20,
      this.childSpacing = 4,
      this.showBorder = true,
      this.animatedChild,
      this.statusWidget,
      this.animatedTime = 200});

  @override
  State<BankBoxExpansionTile> createState() => _BankBoxExpansionTile();
}

class _BankBoxExpansionTile extends State<BankBoxExpansionTile> {
  bool animated = false;
  @override
  Widget build(BuildContext context) {
    return InkWell(
      splashColor: Colors.transparent,
      highlightColor: Colors.transparent,
      onTap: () {
        setState(() {
          animated = !animated;
        });
      },
      child: Column(
        children: [
          AnimatedContainer(
            padding: widget.padding,
            constraints: BoxConstraints(minHeight: animated ? 80 : 28),
            width: double.infinity,
            duration: Duration(milliseconds: widget.animatedTime),
            child: Column(
              children: [
                const Gap(4),
                Row(
                  children: [
                    if (widget.title == null) ...[
                      widget.leading ?? const SizedBox()
                    ] else ...[
                      Expanded(
                        child: FittedBox(
                          alignment: Alignment.centerLeft,
                          fit: BoxFit.scaleDown,
                          child: Row(
                            children: [
                              Column(
                                children: [
                                  Text(
                                    widget.title ?? "",
                                    style: subtitle.copyWith(
                                        fontSize: 14,
                                        fontWeight: FontWeight.w400),
                                  ),
                                ],
                              ),
                              if (widget.statusWidget != null) ...[
                                const Gap(4),
                                widget.statusWidget!
                              ]
                            ],
                          ),
                        ),
                      ),
                    ],
                    Image.asset(
                      animated
                          ? loadAsset("ios_dropup_icon.png")
                          : loadAsset("ios_dropdown_icon.png"),
                      height: widget.actionIconSize,
                      width: widget.actionIconSize,
                      color: widget.iconColor ?? (AppColors.ravenPayGrey3),
                    ),
                  ],
                ),
                Gap(widget.childSpacing),
                AnimatedCrossFade(
                  crossFadeState: animated
                      ? CrossFadeState.showSecond
                      : CrossFadeState.showFirst,
                  firstChild: const SizedBox(width: double.infinity),
                  duration: Duration(milliseconds: widget.animatedTime),
                  secondChild: Column(
                    children: [const Gap(8), widget.animatedChild!],
                  ),
                ),
              ],
            ),
          ),
          Gap(widget.borderSpacing),
          if (widget.showBorder) ...[
            Divider(
              color: AppColors.ravenLightGrey
                  .withOpacity(pluginTheme.isLightTheme ? 0.7 : 0.08),
            ),
          ]
        ],
      ),
    );
  }
}
