import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';

class PoweredByRaven extends StatefulWidget {
  final double fontSize;
  final bool transparent;
  final double paddingBottom;
  final Color? backgroundColor;
  const PoweredByRaven(
      {super.key,
      this.transparent = false,
      this.fontSize = 12,
      this.backgroundColor,
      this.paddingBottom = 0});

  @override
  State<PoweredByRaven> createState() => _PoweredByRavenState();
}

class _PoweredByRavenState extends State<PoweredByRaven> {
  late bool transparent;

  @override
  void initState() {
    if (pluginConfig.theme?.isLightTheme == true) {
      transparent = widget.transparent;
    } else {
      transparent = true;
    }
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return pluginConfig.showLabel
        ? Container(
            color: widget.backgroundColor,
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    Container(
                        padding: const EdgeInsets.symmetric(
                            horizontal: 16, vertical: 8),
                        decoration: BoxDecoration(
                            color: transparent ? null : Colors.white,
                            border: transparent
                                ? Border.all(color: Colors.white)
                                : null,
                            boxShadow: transparent
                                ? null
                                : const [
                                    BoxShadow(
                                        color:
                                            Color.fromARGB(255, 228, 228, 228),
                                        spreadRadius: 1,
                                        blurRadius: 0.5)
                                  ],
                            borderRadius: BorderRadius.circular(16)),
                        child: Row(
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Text(
                              "Powered By",
                              style: subtitle.copyWith(
                                  fontSize: widget.fontSize,
                                  color: transparent
                                      ? Colors.white
                                      : AppColors.darkGrey),
                            ),
                            const Gap(4),
                            Padding(
                              padding: const EdgeInsets.only(bottom: 1),
                              child: Image.asset(loadAsset("raven_logo.png"),
                                  color: transparent ? Colors.white : null,
                                  height: widget.fontSize),
                            )
                          ],
                        )),
                  ],
                ),
                Gap(widget.paddingBottom)
              ],
            ),
          )
        : const SizedBox();
  }
}
