import 'dart:math';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';

class RavenPayCardPinNumberPad extends StatefulWidget {
  final String amount;
  final int? length;
  final bool randomizeKeys;

  final Function(String) onChange;

  const RavenPayCardPinNumberPad({
    super.key,
    required this.amount,
    this.randomizeKeys = false,
    this.length,
    required this.onChange,
  });

  @override
  State<RavenPayCardPinNumberPad> createState() =>
      _RavenPayCardPinNumberPadState();
}

class _RavenPayCardPinNumberPadState extends State<RavenPayCardPinNumberPad> {
  bool shuffled = false;
  List<Widget> keys = [];
  @override
  Widget build(BuildContext context) {
    return Expanded(
        child: Column(
      mainAxisAlignment: MainAxisAlignment.spaceAround,
      children: getKeyPad(),
    ));
  }

  List<Widget> getKeyPad() {
    if (shuffled) {
      return this.keys;
    }
    var keys = <Widget>[
      Expanded(
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.center,
          children: shuffleKeys([
            item("1"),
            item("2"),
            item("3"),
          ]),
        ),
      ),
      Expanded(
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.center,
          children: shuffleKeys([
            item("4"),
            item("5"),
            item("6"),
          ]),
        ),
      ),
      Expanded(
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.center,
          children: shuffleKeys([
            item("7"),
            item("8"),
            item("9"),
          ]),
        ),
      ),
    ];

    keys = shuffleKeys(keys);
    keys.add(Expanded(
        child: Row(
      children: shuffleKeys([
        item('0'),
        const Expanded(child: SizedBox()),
        Expanded(
            child: InkWell(
                highlightColor: Colors.transparent,
                focusColor: Colors.transparent,
                splashColor: Colors.transparent,
                onTap: () async {
                  delete();
                },
                child: Center(
                  child: Padding(
                    padding: const EdgeInsets.only(right: 8),
                    child: Image.asset(
                      loadAsset("arrow_back.png"),
                      color: headling2.color,
                      height: 18,
                      width: 18,
                    ),
                  ),
                ))),
      ]),
    )));

    shuffled = true;
    this.keys = keys;
    return keys;
  }

  List<Widget> shuffleKeys(List<Widget> keys) {
    if (shuffled) {
      return keys;
    }
    final random = Random();
    for (int i = keys.length - 1; i > 0; i--) {
      final int j = random.nextInt(i + 1);
      // Swap elements at i and j
      final Widget temp = keys[i];
      keys[i] = keys[j];
      keys[j] = temp;
    }

    return keys;
  }

  void delete() {
    if (widget.amount.isNotEmpty) {
      widget.onChange(widget.amount.substring(0, widget.amount.length - 1));
    }
  }

  void valueChanged(String val) {
    if (widget.length != null && widget.amount.length >= widget.length!) {
      return;
    }
    widget.onChange(val);
  }

  Widget item(String value) {
    return Expanded(
        child: InkWell(
      highlightColor: Colors.transparent,
      focusColor: Colors.transparent,
      splashColor: Colors.transparent,
      onTap: () async {
        await HapticFeedback.vibrate();
        valueChanged(widget.amount + value);
      },
      child: Container(
        height: 80,
        alignment: Alignment.center,
        child: RavenPayText.heading(
          value,
          color: headling2.color,
          align: TextAlign.center,
        ),
      ),
    ));
  }
}
