import 'package:flutter/material.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';

enum FilterType { ten, thirty, hour }

class StabilityDropDown extends StatelessWidget {
  final Function(FilterType) onChange;
  final FilterType currentValue;
  const StabilityDropDown(
      {Key? key, required this.onChange, required this.currentValue})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
        padding: const EdgeInsets.symmetric(vertical: 4, horizontal: 8),
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(8),
          border: Border.all(
            color: subtitle.color!,
            width: 0.8,
          ),
        ),
        child: Theme(
          data: pluginTheme.isLightTheme ? ThemeData.light() : ThemeData.dark(),
          child: DropdownButtonHideUnderline(
              child: DropdownButton<FilterType>(
                  onChanged: (val) {
                    if (val == null) {
                      return;
                    }
                    onChange(val);
                  },
                  isDense: true,
                  value: currentValue,
                  borderRadius: BorderRadius.circular(14),
                  items: [
                DropdownMenuItem(
                  value: FilterType.ten,
                  child: Text(
                    '10Mins',
                    style: subtitle.copyWith(
                      fontSize: 12,
                      color: subtitle.color,
                      fontWeight: FontWeight.w400,
                    ),
                  ),
                ),
                DropdownMenuItem(
                  value: FilterType.thirty,
                  child: Text(
                    '30Mins',
                    style: subtitle.copyWith(
                      color: subtitle.color,
                      fontSize: 12,
                      fontWeight: FontWeight.w400,
                    ),
                  ),
                ),
                DropdownMenuItem(
                  value: FilterType.hour,
                  child: Text(
                    '1Hour',
                    style: subtitle.copyWith(
                      color: subtitle.color,
                      fontSize: 12,
                      fontWeight: FontWeight.w400,
                      // color: kWhite,
                    ),
                  ),
                ),
              ])),
        ));
  }
}
