import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/helpers/logger.dart';
import 'package:mobile_pos/src/models/raven_const.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/card_payment/widget/share_receipt_sheet.dart';

class CardFailurePage extends StatelessWidget {
  const CardFailurePage(
      {super.key, this.reason, this.rrn, this.paymentType = PaymentType.card});
  final String? reason;
  final String? rrn;
  final PaymentType paymentType;

  @override
  Widget build(BuildContext context) {
    logData(rrn ?? 'no RRN');

    return RavenPayScaffold(
        bottomNavigationBar: Container(
          width: double.infinity,
          height: 80,
          decoration: BoxDecoration(
              color: pluginTheme.isLightTheme ? const Color(0xFFF7F8F7) : null,
              border: Border(
                  top: BorderSide(
                      color: const Color(0xFFCCCCCC)
                          .withOpacity(pluginTheme.isLightTheme ? 1 : 0.1)))),
          child: Row(
            children: [
              if (paymentType == PaymentType.card) ...[
                Expanded(
                    child: InkWell(
                  splashColor: Colors.transparent,
                  highlightColor: Colors.transparent,
                  onTap: () {
                    showRavenPayBottomSheet(context,
                        child: ShareReceiptSheet(
                          rrn: rrn ?? "",
                          category: bluetoothModel?.category,
                        ));
                  },
                  child: Container(
                    height: 100,
                    decoration: BoxDecoration(
                        border: Border(
                            right: BorderSide(
                                color: const Color(0xFFCCCCCC).withOpacity(
                                    pluginTheme.isLightTheme ? 1 : 0.1)))),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: [
                        SizedBox(
                            height: 24,
                            width: 24,
                            child: Image.asset(
                              loadAsset('share.png'),
                              color: headling2.color,
                            )),
                        const Gap(8),
                        Text('Share Receipt',
                            style: subtitle.copyWith(fontSize: 12))
                      ],
                    ),
                  ),
                )),
              ],
              Expanded(
                  child: InkWell(
                splashColor: Colors.transparent,
                highlightColor: Colors.transparent,
                onTap: () {
                  Navigator.of(context).pop();
                },
                child: Container(
                  height: 100,
                  decoration: BoxDecoration(
                      border: Border(
                          right: BorderSide(
                              color: const Color(0xFFCCCCCC).withOpacity(
                                  pluginTheme.isLightTheme ? 1 : 0.1)))),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      SizedBox(
                          height: 24,
                          width: 24,
                          child: Image.asset(
                            loadAsset('close_icon.png'),
                            color: headling2.color,
                          )),
                      const Gap(8),
                      Text('Close', style: subtitle.copyWith(fontSize: 12))
                    ],
                  ),
                ),
              ))
            ],
          ),
        ),
        body: Padding(
          padding: const EdgeInsets.all(20.0),
          child: SizedBox(
            width: double.infinity,
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                SizedBox(
                    width: 100,
                    height: 100,
                    child: Image.asset(loadAsset('warning_red.png'))),
                // Gap(8),
                Text(
                  paymentType == PaymentType.checkBalance
                      ? 'Failed'
                      : 'Payment Failed',
                  textAlign: TextAlign.center,
                  style: headling1.copyWith(fontSize: 22),
                ),
                const Gap(4),

                Text(
                  reason ??
                      (paymentType == PaymentType.checkBalance
                          ? 'There was an issue checking your card balance.'
                          : 'There was an issue charging your card for this transaction.'),
                  style: subtitle.copyWith(fontWeight: FontWeight.w500),
                  textAlign: TextAlign.center,
                ),
              ],
            ),
          ),
        ));
  }
}
