import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';
import 'package:qr_flutter_new/qr_flutter.dart';

class QrCodeReceiptShare extends StatelessWidget {
  final String data;

  const QrCodeReceiptShare({super.key, required this.data});

  @override
  Widget build(BuildContext context) {
    double qrSize = 220;
    return Padding(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          const Gap(20),
          const RavenPayBottomSheetCapsule(),
          const Gap(24),
          Row(
            children: [
              Expanded(
                  child:
                      Text("QR Code", style: headling1.copyWith(fontSize: 20))),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: RoundedItemContainer(
                    asset: "cancel_icon.png",
                    imageColor: pluginTheme.isLightTheme ? null : Colors.white),
              ),
            ],
          ),
          const Gap(20),
          Container(
              padding: const EdgeInsets.symmetric(horizontal: 12),
              width: double.infinity,
              color: pluginTheme.getFGColor,
              child: Column(
                mainAxisAlignment: MainAxisAlignment.end,
                children: [
                  const Gap(24),
                  Container(
                      decoration: BoxDecoration(
                          border: Border.all(color: Colors.transparent),
                          color: Colors.white,
                          borderRadius: BorderRadius.circular(8)),
                      height: qrSize,
                      width: qrSize,
                      child: QrImageView(
                        gradient: RadialGradient(colors: [
                          pluginTheme.primaryColor.withOpacity(0.8),
                          pluginTheme.primaryColor,
                          Colors.black
                        ]),
                        gapless: false,
                        dataModuleStyle: const QrDataModuleStyle(
                            dataModuleShape: QrDataModuleShape.circle),
                        data: data,
                        eyeStyle: const QrEyeStyle(
                            borderRadius: 14, eyeShape: QrEyeShape.square),
                        drawCircle: true,
                        circleColor: Colors.white,
                        embeddedImageStyle: QrEmbeddedImageStyle(
                          safeArea: true,
                          size: Size(qrSize * 0.12, qrSize * 0.12),
                        ),
                      )),
                  const Gap(16),
                  Container(
                    padding:
                        const EdgeInsets.symmetric(vertical: 8, horizontal: 8),
                    decoration: BoxDecoration(
                        border: Border.all(color: pluginTheme.secondaryColor),
                        color: AppColors.lightOrange,
                        borderRadius: BorderRadius.circular(8)),
                    child: Row(children: [
                      Icon(Icons.info, color: pluginTheme.secondaryColor),
                      const Gap(4),
                      Expanded(
                        child: Text(
                            "Tell your customer to scan this QR Code to see their Receipt.",
                            style: subtitle.copyWith(
                                color: AppColors.ravenDark,
                                fontSize: 10,
                                fontWeight: FontWeight.w400)),
                      ),
                      const Gap(24)
                    ]),
                  ),
                  const Gap(12),
                ],
              )),
          const Gap(24),
        ],
      ),
    );
  }
}
