import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/shared_widgets/coming_soon_badge.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/pay_with_code/pay_with_code.dart';
import 'package:mobile_pos/src/shared_widgets/powerby_by_raven_widget.dart';
import 'package:mobile_pos/src/shared_widgets/purchase_amount.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';
import 'package:mobile_pos/src/views/terminal/widget/termianl_settings.dart';

class PaymentMethod extends StatefulWidget {
  const PaymentMethod({super.key});

  @override
  State<PaymentMethod> createState() => _PaymentMethodState();
}

class _PaymentMethodState extends State<PaymentMethod> {
  bool isBusy = false;
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          const Gap(16),
          const RavenPayBottomSheetCapsule(),
          const Gap(24),
          Align(
            alignment: Alignment.centerLeft,
            child: Text("Select Payment Method",
                style: headling2.copyWith(
                    fontSize: 20, color: pluginTheme.primaryColor)),
          ),
          const Gap(24),
          item(
              context: context,
              asset: "card_payment.png",
              name: "Card Payment",
              onTap: () {
                return 1;
              }),
          const Gap(8),
          const BankBoxDivider(
            height: 12,
          ),
          const Gap(8),
          item(
              comingSoon: true,
              context: context,
              asset: "generate_pay_code.png",
              name: "Paycode",
              onTap: () {
                pushRoute(context, const PayWithCode());
              }),
          const Gap(24),
          const PoweredByRaven(fontSize: 9),
          const BottomNavSpacer()
        ],
      ),
    );
  }

  Widget item({
    required BuildContext context,
    required String name,
    required String asset,
    required Function onTap,
    bool comingSoon = false,
  }) {
    return InkWell(
      highlightColor: Colors.transparent,
      splashColor: Colors.transparent,
      onTap: comingSoon
          ? null
          : () {
              Navigator.pop(context, onTap());
            },
      child: Row(
        children: [
          RoundedItemContainer(
            showContainerColor: false,
            imageColor: headling2.color,
            asset: asset,
            size: 40,
            padding: 9,
          ),
          const Gap(16),
          Expanded(
              child: Row(
            children: [
              Text(name, style: headling2.copyWith(fontSize: 15)),
              if (comingSoon) ...[const Gap(8), const ComingSoonBadge()]
            ],
          )),
          Icon(
            Icons.arrow_forward_ios,
            size: 16,
            color: headling2.color,
          )
        ],
      ),
    );
  }
}
