// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_textfeild.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';

class AddAlertSheet extends StatefulWidget {
  final String serial;
  final String tid;
  const AddAlertSheet({super.key, required this.serial, required this.tid});

  @override
  State<AddAlertSheet> createState() => _AddAlertSheetState();
}

class _AddAlertSheetState extends State<AddAlertSheet> {
  bool isBusy = false;
  @override
  void initState() {
    super.initState();
  }

  final firstnameController = TextEditingController();
  final lastnameController = TextEditingController();
  final phoneController = TextEditingController();

  final GlobalKey<FormState> formKey = GlobalKey<FormState>();
  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding) +
          EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
      child: Form(
        key: formKey,
        child: SingleChildScrollView(
          child: Column(
            mainAxisSize: MainAxisSize.min,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              const Gap(16),
              const RavenPayBottomSheetCapsule(),
              const Gap(24),
              Row(
                children: [
                  Expanded(
                    child: Text(
                      "Add Alert Phone number",
                      style: headling1.copyWith(fontSize: 20),
                    ),
                  ),
                  GestureDetector(
                    onTap: () {
                      Navigator.pop(context);
                    },
                    child: const RoundedItemContainer(asset: "cancel_icon.png"),
                  )
                ],
              ),
              const Gap(4),
              Text(
                  "Ensure this phone number is connected to Whatsapp and is active.",
                  style: subtitle2.copyWith(fontSize: 14)),
              const Gap(24),
              RavenPayTextField(
                hintText: "Firstname",
                onChanged: (val) {
                  setState(() {});
                },
                controller: firstnameController,
                labelText: "Enter your firstname",
                validator: (data) => validateInput(
                    minCount: 3, data, errorMessage: 'invalid firstname'),
                filledColor:
                    pluginTheme.isLightTheme ? const Color(0xffF7F8F7) : null,
              ),
              const Gap(20),
              RavenPayTextField(
                onChanged: (val) {
                  setState(() {});
                },
                validator: (data) => validateInput(
                    minCount: 3, data, errorMessage: 'invalid lastname'),
                hintText: "lastname",
                controller: lastnameController,
                labelText: "Enter your lastname",
                filledColor:
                    pluginTheme.isLightTheme ? const Color(0xffF7F8F7) : null,
              ),
              const Gap(20),
              RavenPayTextField(
                counterText: '',
                maxLength: 11,
                validator: (data) => validateInput(
                    minCount: 10, data, errorMessage: 'invalid mobile number'),
                inputType: TextInputType.phone,
                controller: phoneController,
                isPhone: true,
                onChanged: (val) {
                  setState(() {});
                },
                labelText: "Phone Number",
              ),
              Gap(size.height * 0.14),
              RavenPayButton(
                  busy: isBusy,
                  buttonText: "Proceed",
                  onPressed: () async {
                    addAlertNumber();
                  }),
              const Gap(30),
            ],
          ),
        ),
      ),
    );
  }

  void addAlertNumber() async {
    if (!formKey.currentState!.validate()) {
      return;
    }

    String refinedPhone = '';
    if (phoneController.text.length == 10) {
      refinedPhone = '0${phoneController.text}';
    } else {
      refinedPhone = phoneController.text;
    }
    isBusy = true;
    setState(() {});
    var response = await ApiRequests.addAlertNumber(
        phoneNumber: refinedPhone,
        tid: widget.tid,
        serial: widget.serial,
        firstname: firstnameController.text,
        lastname: lastnameController.text);
    isBusy = false;
    setState(() {});
    if (response) {
      Navigator.pop(context);
    }
  }
}
