import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:intl/intl.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/bankbox_transaction_model.dart';
import 'package:mobile_pos/src/shared_widgets/empty_state.dart';
import 'package:mobile_pos/src/shared_widgets/transaction_item.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:simple_grouped_listview/simple_grouped_listview.dart';
import 'package:sticky_headers/sticky_headers/widget.dart';

class TerminalTransactionView extends StatelessWidget {
  final Function onSwapRefresh;
  const TerminalTransactionView(
      {super.key, required this.transactions, required this.onSwapRefresh});

  final List<Transaction> transactions;

  @override
  Widget build(BuildContext context) {
    return transactions.isEmpty
        ? const Center(
            child: BankBoxEmptyState(
              statement: 'No transactions yet',
            ),
          )
        : RefreshIndicator(
            backgroundColor: pluginTheme.getFGColor,
            onRefresh: () async {
              onSwapRefresh();
              await Future.delayed(const Duration(seconds: 3));
            },
            child: ClipRRect(
              borderRadius: BorderRadius.circular(12),
              child: GroupedListView(
                padding: const EdgeInsets.only(bottom: 84),
                items: transactions,
                itemGrouper: (Transaction item) {
                  return DateFormatter.format(item.createdAt,
                      format: 'yyyy/MM/dd');
                },
                customBuilder: (BuildContext context, String header,
                    List<IndexedItem<Transaction>> items) {
                  return Container(
                    margin: const EdgeInsets.symmetric(vertical: 12),
                    child: StickyHeader(
                      header: Container(
                        width: double.infinity,
                        decoration: BoxDecoration(
                            color: pluginTheme.getFGColor,
                            borderRadius: BorderRadius.only(
                                topLeft: Radius.circular(_borderRadius),
                                topRight: Radius.circular(_borderRadius))),
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            const Gap(10),
                            Padding(
                              padding:
                                  const EdgeInsets.only(left: 14.0, top: 4),
                              child: Text(
                                  DateFormatter.format(
                                      DateFormat('yyyy/MM/dd').parse(header),
                                      format: 'MMMM d'),
                                  // header,
                                  style: headling1.copyWith(
                                      fontSize: 12,
                                      fontWeight: FontWeight.w500)),
                            ),
                          ],
                        ),
                      ),
                      content: ListView.builder(
                        itemCount: items.length,
                        shrinkWrap: true,
                        physics: const NeverScrollableScrollPhysics(),
                        itemBuilder: (context, int index) => Container(
                            decoration: BoxDecoration(
                              color: pluginTheme.getFGColor,
                              borderRadius: BorderRadius.only(
                                  topLeft: Radius.zero,
                                  topRight: Radius.zero,
                                  bottomLeft: index == items.length - 1
                                      ? Radius.circular(_borderRadius)
                                      : Radius.zero,
                                  bottomRight: index == items.length - 1
                                      ? Radius.circular(_borderRadius)
                                      : Radius.zero),
                            ),
                            padding: const EdgeInsets.symmetric(horizontal: 16),
                            child: Column(
                              children: [
                                BankBoxTransactionItem(
                                  model: items[index].item,
                                  showBorder: !(index == items.length - 1),
                                ),
                              ],
                            )),
                      ),
                    ),
                  );
                },
              ),
            ),
          );
  }

  double get _borderRadius => 14;
}
