import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/shared_widgets/business_type_sheet.dart';
import 'package:mobile_pos/src/shared_widgets/powerby_by_raven_widget.dart';
import 'package:mobile_pos/src/shared_widgets/purchase_amount.dart';
import 'package:mobile_pos/src/shared_widgets/raven_pay_appbar.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_textfeild.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/update_user_info_2.dart';

import 'widget/step_widget.dart';

class UpdateUserInfo1 extends StatefulWidget {
  const UpdateUserInfo1({super.key});

  @override
  State<UpdateUserInfo1> createState() => _UpdateUserInfo1State();
}

class _UpdateUserInfo1State extends State<UpdateUserInfo1> {
  final businessName = TextEditingController();
  final businessType = TextEditingController();
  final nin = TextEditingController();
  final businessBVN = TextEditingController();

  final GlobalKey<FormState> formKey = GlobalKey<FormState>();

  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        bottomNavigationBar: Padding(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              RavenPayButton(
                  buttonText: "Proceed",
                  onPressed: () {
                    if (businessName.text.length < 2) {
                      showSnack(context, "please provide a valid name");
                      return;
                    }
                    if (businessType.text.length < 2) {
                      showSnack(context, "please select business type");
                      return;
                    }
                    if (nin.text.length < 10) {
                      showSnack(context, "please provide your NIN");
                      return;
                    }
                    if (businessBVN.text.length < 10) {
                      showSnack(context, "invalid BVN provided...");
                      return;
                    }
                    pushRoute(
                        context,
                        UpdateUserInfo2(
                          name: businessName.text,
                          businessBVN: businessBVN.text,
                          businessType: businessType.text,
                          nin: nin.text,
                        ));
                  }),
              const Gap(24),
              const PoweredByRaven(fontSize: 9),
              const BottomNavSpacer(),
            ],
          ),
        ),
        appBar: ravenPayAppBar(),
        body: SingleChildScrollView(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Form(
            key: formKey,
            child: Column(
              children: [
                const Gap(12),
                Align(
                    alignment: Alignment.centerLeft,
                    child: Text("Business Information", style: headling1)),
                const Gap(8),
                Text(
                  "We need this information before you can proceed with your terminal request.",
                  style: subtitle2,
                ),
                const Gap(20),
                const BankBoxStep(),
                const Gap(16),
                RavenPayTextField(
                  labelText: "Business Name",
                  hintText: "Enter a business name.",
                  controller: businessName,
                  onChanged: (val) {
                    businessName.text = businessName.text.toUpperCase();
                  },
                ),
                const Gap(16),
                RavenPayTextField(
                  isDropdown: true,
                  readOnly: true,
                  onTap: () async {
                    var choice = await showRavenPayBottomSheet(context,
                        child: const BusinessTypeSheet());
                    if (choice != null) {
                      setState(() {
                        businessType.text = choice;
                      });
                    }
                  },
                  labelText: "Business Type",
                  hintText: "Select business type.",
                  controller: businessType,
                ),
                const Gap(16),
                RavenPayTextField(
                  counterText: "",
                  maxLength: 11,
                  labelText: "NIN Details",
                  hintText: "Enter NIN here",
                  inputType: TextInputType.number,
                  controller: nin,
                ),
                const Gap(16),
                RavenPayTextField(
                  counterText: "",
                  maxLength: 11,
                  inputType: TextInputType.number,
                  labelText: "BVN Details",
                  hintText: "Enter BVN here",
                  controller: businessBVN,
                ),
                const Gap(42),
              ],
            ),
          ),
        ));
  }
}
