// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/lga_bottom_sheet.dart';
import 'package:mobile_pos/src/shared_widgets/powerby_by_raven_widget.dart';
import 'package:mobile_pos/src/shared_widgets/progress_dialog.dart';
import 'package:mobile_pos/src/shared_widgets/purchase_amount.dart';
import 'package:mobile_pos/src/shared_widgets/raven_pay_appbar.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_textfeild.dart';
import 'package:mobile_pos/src/shared_widgets/state_of_origin_sheet.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/request_terminal_1.dart';

import 'widget/step_widget.dart';

class UpdateUserInfo2 extends StatefulWidget {
  final String name;
  final String businessType;
  final String nin;
  final String businessBVN;

  const UpdateUserInfo2(
      {super.key,
      required this.name,
      required this.businessBVN,
      required this.nin,
      required this.businessType});

  @override
  State<UpdateUserInfo2> createState() => _UpdateUserInfo2State();
}

class _UpdateUserInfo2State extends State<UpdateUserInfo2> {
  final businessAddress = TextEditingController();
  final businessState = TextEditingController();
  final businessLGA = TextEditingController();

  final GlobalKey<FormState> formKey = GlobalKey<FormState>();

  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        bottomNavigationBar: Padding(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              RavenPayButton(
                buttonText: "Save Information",
                onPressed: () => updateBusiness(),
              ),
              const Gap(24),
              const PoweredByRaven(fontSize: 9),
              const BottomNavSpacer(),
            ],
          ),
        ),
        appBar: ravenPayAppBar(),
        body: SingleChildScrollView(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Form(
            key: formKey,
            child: Column(
              children: [
                const Gap(12),
                Align(
                    alignment: Alignment.centerLeft,
                    child: Text("Business Information", style: headling1)),
                const Gap(8),
                Text(
                  "We need this information before you can proceed with your terminal request.",
                  style: subtitle2,
                ),
                const Gap(20),
                const BankBoxStep(
                  step: 2,
                ),
                const Gap(16),
                RavenPayTextField(
                  labelText: "Business address",
                  hintText: "Enter a business address.",
                  controller: businessAddress,
                ),
                const Gap(16),
                RavenPayTextField(
                  isDropdown: true,
                  labelText: "State",
                  onTap: () async {
                    var choice = await showRavenPayBottomSheet(context,
                        child: const StateOfOriginSheet());

                    if (choice != null) {
                      setState(() {
                        businessLGA.text = "";
                        businessState.text = choice;
                      });
                    }
                  },
                  hintText: "Select State.",
                  readOnly: true,
                  controller: businessState,
                ),
                const Gap(16),
                RavenPayTextField(
                  isDropdown: true,
                  readOnly: true,
                  labelText: "LGA",
                  onTap: () async {
                    var choice = await showRavenPayBottomSheet(context,
                        child: LGASheet(
                          state: businessState.text,
                        ));
                    if (choice != null) {
                      businessLGA.text = choice;
                    }
                  },
                  hintText: "Select LGA.",
                  controller: businessLGA,
                ),
                const Gap(16),
                const Gap(42),
              ],
            ),
          ),
        ));
  }

  void updateBusiness() async {
    if (businessAddress.text.length < 5) {
      showSnack(context, "invalid address... please provide a valid address");
      return;
    }
    if (businessState.text.length < 2) {
      showSnack(context, "please select state...");
      return;
    }
    if (businessLGA.text.length < 2) {
      showSnack(context, "please select LGA");
      return;
    }
    final form = formKey.currentState;

    if (form!.validate()) {
      showDialog(
          barrierDismissible: true,
          context: context,
          builder: (BuildContext context) => const ProgressDialog(
                status: 'Updating info...',
              ));
      final success = await ApiRequests.updateUserDetails(
        businessName: widget.name,
        businessType: widget.businessType,
        businessNIN: widget.nin,
        businessBVN: widget.businessBVN,
        businessAddress: businessAddress.text,
        state: businessState.text,
        lga: businessLGA.text,
      );
      Navigator.pop(context);
      if (success) {
        pushRoute(context, const RequestTerminal1());
      }
    }
  }
}
